@@ -42,6 +42,7 @@ from hdl_checker.diagnostics import (  # pylint: disable=unused-import
     PathLibraryIsNotUnique,
     PathNotInProjectFile,
 )
+from hdl_checker.exceptions import UnknownTypeExtension
 from hdl_checker.parser_utils import flattenConfig, getSourceParserFromPath
 from hdl_checker.parsers.elements.dependency_spec import (
     BaseDependencySpec,
@@ -443,9 +444,15 @@ class Database(HashableByKey):  # pylint: disable=too-many-instance-attributes
         """
         _logger.debug("Parsing %s", path)
 
-        src_parser = getSourceParserFromPath(path)
-        design_units = src_parser.getDesignUnits()
-        dependencies = src_parser.getDependencies()
+        try:
+            src_parser = getSourceParserFromPath(path)
+            design_units = src_parser.getDesignUnits()
+            dependencies = src_parser.getDependencies()
+        except UnknownTypeExtension:
+            # Not a file extension we know how to parse, leave design units and
+            # dependencies empty
+            design_units = set()
+            dependencies = set()
 
         with self._lock:
             # Update the timestamp
@@ -855,7 +862,13 @@ class Database(HashableByKey):  # pylint: disable=too-many-instance-attributes
         database that refer to the given design unit. Search is done by
         matching library and name.
         """
-        library = self.getLibrary(unit.owner)
+        # Use the unit's library if the unit is a dependency
+        if isinstance(unit, BaseDependencySpec):
+            library = unit.library
+        else:
+            # If the unit is either a VHDL or a Verilog design unit (i.e.,
+            # entities, modules, packages, etc), then use the owner's library
+            library = self.getLibrary(unit.owner)
 
         return (
             dependency
