@@ -21,7 +21,7 @@ import logging
 from os import getpid
 from os import path as p
 from tempfile import mkdtemp
-from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import Any, Callable, Iterable, List, Optional, Set, Tuple, Union
 
 from pygls.features import (
     DEFINITION,
@@ -58,11 +58,15 @@ from pygls.uris import from_fs_path, to_fs_path
 from tabulate import tabulate
 
 from hdl_checker import DEFAULT_LIBRARY, DEFAULT_PROJECT_FILE
-from hdl_checker.base_server import BaseServer
 from hdl_checker.config_generators.simple_finder import SimpleFinder
+from hdl_checker.core import HdlCheckerCore
 from hdl_checker.diagnostics import CheckerDiagnostic, DiagType
 from hdl_checker.exceptions import UnknownParameterError
-from hdl_checker.parsers.elements.dependency_spec import BaseDependencySpec
+from hdl_checker.parsers.elements.dependency_spec import (
+    BaseDependencySpec,
+    IncludedPath,
+    RequiredDesignUnit,
+)
 from hdl_checker.parsers.elements.design_unit import (
     VerilogDesignUnit,
     VhdlDesignUnit,
@@ -70,7 +74,12 @@ from hdl_checker.parsers.elements.design_unit import (
 )
 from hdl_checker.path import Path, TemporaryPath
 from hdl_checker.types import ConfigFileOrigin  # , Location
-from hdl_checker.utils import getTemporaryFilename, logCalls, onNewReleaseFound
+from hdl_checker.utils import (
+    debounce,
+    getTemporaryFilename,
+    logCalls,
+    onNewReleaseFound,
+)
 
 _logger = logging.getLogger(__name__)
 
@@ -119,7 +128,7 @@ def checkerDiagToLspDict(diag: CheckerDiagnostic) -> Diagnostic:
     )
 
 
-class Server(BaseServer):
+class Server(HdlCheckerCore):
     """
     HDL Checker project builder class
     """
@@ -174,6 +183,7 @@ class HdlCheckerLanguageServer(LanguageServer):
             _logger.debug("Server was not initialized, using a temporary one")
             root_dir = mkdtemp(prefix="temp_hdl_checker_pid{}_".format(getpid()))
             self._checker = Server(self, root_dir=TemporaryPath(root_dir))
+            _logger.debug("Temporary server %s is ready", self._checker)
         return self._checker
 
     def showInfo(self, msg: str) -> None:
@@ -253,6 +263,7 @@ class HdlCheckerLanguageServer(LanguageServer):
 
         return path
 
+    @debounce(LINT_DEBOUNCE_S, keyed_by="uri")
     def lint(self, uri: URI, is_saved: bool) -> None:
         """
         Check a file for lint errors
@@ -268,15 +279,14 @@ class HdlCheckerLanguageServer(LanguageServer):
         paths.add(Path(to_fs_path(uri)))
 
         for path in paths:
-            diags_to_publish = {
-                checkerDiagToLspDict(diag) for diag in diags if diag.filename == path
-            }
-            if diags_to_publish:
-                self.lsp.publish_diagnostics(
-                    from_fs_path(str(path)), tuple(diags_to_publish)
-                )
-            else:
-                _logger.debug("No diagnostics for %s", path)
+            self.lsp.publish_diagnostics(
+                from_fs_path(str(path)),
+                tuple(
+                    checkerDiagToLspDict(diag)
+                    for diag in diags
+                    if diag.filename == path
+                ),
+            )
 
     def _getDiags(self, doc_uri: URI, is_saved: bool) -> Iterable[CheckerDiagnostic]:
         """
@@ -301,7 +311,7 @@ class HdlCheckerLanguageServer(LanguageServer):
     def references(self, params: ReferenceParams) -> Optional[List[Location]]:
         "Tries to find references for the selected element"
 
-        element = self._getElementAtPosition(
+        element = self.getElementAtPosition(
             Path(to_fs_path(params.textDocument.uri)), params.position
         )
 
@@ -359,7 +369,7 @@ class HdlCheckerLanguageServer(LanguageServer):
 
         return text
 
-    def _getBuildSequenceForHover(self, path: Path) -> str:
+    def getBuildSequenceForHover(self, path: Path) -> str:
         """
         Return a formatted text with the build sequence for the given path
         """
@@ -392,22 +402,27 @@ class HdlCheckerLanguageServer(LanguageServer):
             ),
         )
 
-    def _getDependencyInfoForHover(self, dependency):
+    def getDependencyInfoForHover(self, dependency):
         # type: (BaseDependencySpec) -> str
         """
         Report which source defines a given dependency when the user hovers
         over its name
         """
-        # If that doesn't match, check for dependencies
-        info = self.checker.resolveDependencyToPath(dependency)
-        if info is not None:
-            return self._format('Path "{}", library "{}"'.format(info[0], info[1]))
+        if isinstance(dependency, RequiredDesignUnit):
+            info = self.checker.resolveDependencyToPath(dependency)
+            if info is not None:
+                return self._format('Path "{}", library "{}"'.format(info[0], info[1]))
+            return "Couldn't find a source defining '{}.{}'".format(
+                dependency.library, dependency.name
+            )
 
-        return "Couldn't find a source defining '{}.{}'".format(
-            dependency.library, dependency.name
-        )
+        if isinstance(dependency, IncludedPath):
+            info = self.checker.database.resolveIncludedPath(dependency)
+            if info is not None:
+                return self._format('Path "{}"'.format(info))
+        return "Couldn't find a source defining '{}'".format(dependency.name)
 
-    def _getElementAtPosition(
+    def getElementAtPosition(
         self, path: Path, position: Position
     ) -> Union[BaseDependencySpec, tAnyDesignUnit, None]:
         """
@@ -427,9 +442,13 @@ class HdlCheckerLanguageServer(LanguageServer):
         return None
 
     def hover(self, params: HoverParams) -> Optional[Hover]:
+        """
+        Handles HoverParams and produces a Hover object if a known element is
+        found within the given location
+        """
         path = Path(to_fs_path(params.textDocument.uri))
         # Check if the element under the cursor matches something we know
-        element = self._getElementAtPosition(path, params.position)
+        element = self.getElementAtPosition(path, params.position)
 
         _logger.debug("Getting info from %s", element)
 
@@ -439,9 +458,9 @@ class HdlCheckerLanguageServer(LanguageServer):
             return None
 
         if isinstance(element, (VerilogDesignUnit, VhdlDesignUnit)):
-            contents = self._getBuildSequenceForHover(path)
+            contents = self.getBuildSequenceForHover(path)
         else:
-            contents = self._getDependencyInfoForHover(element)
+            contents = self.getDependencyInfoForHover(element)
 
         return Hover(
             contents=contents,
@@ -459,7 +478,10 @@ class HdlCheckerLanguageServer(LanguageServer):
     def definitions(
         self, params: TextDocumentPositionParams
     ) -> Optional[List[Location]]:
-        dependency = self._getElementAtPosition(
+        """
+        Returns known definitions found in the given location
+        """
+        dependency = self.getElementAtPosition(
             Path(to_fs_path(params.textDocument.uri)), params.position
         )
 
@@ -468,7 +490,7 @@ class HdlCheckerLanguageServer(LanguageServer):
             return []
 
         # Work out where this dependency refers to
-        info = self.checker.resolveDependencyToPath(dependency)
+        info = self.checker.resolveDependency(dependency)
 
         if info is None:
             _logger.debug("Unable to resolve %s to a path", dependency)
@@ -480,6 +502,15 @@ class HdlCheckerLanguageServer(LanguageServer):
         target_path, _ = info
         target_uri = from_fs_path(str(target_path))
 
+        if not target_path:
+            _logger.debug("Unable to resolve %s to a path", dependency)
+            return []
+
+        # Included paths are dependencies but they're referred to by path, so
+        # we return a definition to point to the beginning of the file
+        if isinstance(dependency, IncludedPath):
+            return [Location(target_uri, Range(Position(0, 0), Position(0, 0),),)]
+
         locations: List[Location] = []
 
         # Get the design unit that has matched the dependency to extract the
