@@ -16,21 +16,17 @@
 # along with HDL Checker.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=missing-docstring
-# pylint: disable=protected-access
-# pylint: disable=invalid-name
 
 import asyncio
 import json
 import logging
 import os
 import os.path as p
-from tempfile import mkdtemp
 from threading import Thread
 from typing import Any, List, Optional, Union
 
-import parameterized  # type: ignore
 import unittest2  # type: ignore
-from mock import Mock, patch
+from mock import patch
 from pygls import features, uris
 from pygls.server import LanguageServer
 from pygls.types import (
@@ -43,7 +39,6 @@ from pygls.types import (
     HoverParams,
     InitializeParams,
     MarkupKind,
-    MessageType,
     Position,
     PublishDiagnosticsAbstract,
     Range,
@@ -58,8 +53,11 @@ from pygls.types import (
 )
 from tabulate import tabulate
 
+from hdl_checker.tests import getTestTempPath, setupTestSuport, toCheckerDiagnostic
+
 import hdl_checker
-from hdl_checker import DEFAULT_LIBRARY
+from hdl_checker import DEFAULT_LIBRARY, lsp
+from hdl_checker.diagnostics import CheckerDiagnostic
 from hdl_checker.parsers.elements.dependency_spec import RequiredDesignUnit
 from hdl_checker.parsers.elements.design_unit import (
     DesignUnitType,
@@ -67,18 +65,9 @@ from hdl_checker.parsers.elements.design_unit import (
     VhdlDesignUnit,
 )
 from hdl_checker.parsers.elements.identifier import Identifier
-from hdl_checker.path import Path, TemporaryPath
+from hdl_checker.path import Path
 from hdl_checker.types import Location
-
-from hdl_checker.tests import (  # isort:skip
-    toCheckerDiagnostic,
-    getTestTempPath,
-    setupTestSuport,
-)
-
-from hdl_checker import lsp  # isort:skip
-from hdl_checker.diagnostics import CheckerDiagnostic, DiagType  # isort:skip
-from hdl_checker.utils import ON_WINDOWS  # isort:skip
+from hdl_checker.utils import ON_WINDOWS
 
 _logger = logging.getLogger(__name__)
 
@@ -117,68 +106,6 @@ if ON_WINDOWS:
     TEST_PROJECT = TEST_PROJECT.lower()
 
 
-class TestCheckerDiagToLspDict(unittest2.TestCase):
-    @parameterized.parameterized.expand(
-        [
-            (DiagType.INFO, DiagnosticSeverity.Information),
-            (DiagType.STYLE_INFO, DiagnosticSeverity.Information),
-            (DiagType.STYLE_WARNING, DiagnosticSeverity.Information),
-            (DiagType.STYLE_ERROR, DiagnosticSeverity.Information),
-            (DiagType.WARNING, DiagnosticSeverity.Warning),
-            (DiagType.ERROR, DiagnosticSeverity.Error),
-            (DiagType.NONE, DiagnosticSeverity.Error),
-        ]
-    )
-    def test_converting_to_lsp(self, diag_type, severity):
-        # type: (...) -> Any
-        _logger.info("Running %s and %s", diag_type, severity)
-
-        diag = lsp.checkerDiagToLspDict(
-            CheckerDiagnostic(
-                checker="hdl_checker test",
-                text="some diag",
-                filename=Path("filename"),
-                line_number=0,
-                column_number=0,
-                error_code="error code",
-                severity=diag_type,
-            )
-        )
-
-        self.assertEqual(diag.code, "error code")
-        self.assertEqual(diag.source, "hdl_checker test")
-        self.assertEqual(diag.message, "some diag")
-        self.assertEqual(diag.severity, severity)
-        self.assertEqual(
-            diag.range,
-            Range(
-                start=Position(line=0, character=0), end=Position(line=0, character=0),
-            ),
-        )
-
-    def test_workspace_notify(self) -> None:  # pylint: disable=no-self-use
-        workspace = Mock()
-        workspace.show_message = Mock()
-
-        server = lsp.Server(
-            workspace, root_dir=TemporaryPath(mkdtemp(prefix="hdl_checker_"))
-        )
-        workspace.show_message.reset_mock()
-
-        server._handleUiInfo("some info")  # pylint: disable=protected-access
-        workspace.show_message.assert_called_once_with("some info", MessageType.Info)
-        workspace.show_message.reset_mock()
-
-        server._handleUiWarning("some warning")  # pylint: disable=protected-access
-        workspace.show_message.assert_called_once_with(
-            "some warning", MessageType.Warning
-        )
-        workspace.show_message.reset_mock()
-
-        server._handleUiError("some error")  # pylint: disable=protected-access
-        workspace.show_message.assert_called_once_with("some error", MessageType.Error)
-
-
 class _LspHelper(unittest2.TestCase):
     def _createClientServerPair(self, params: Optional[InitializeParams]):
         # pylint: disable=attribute-defined-outside-init
@@ -197,8 +124,8 @@ class _LspHelper(unittest2.TestCase):
         self.server_diagnostics = []  # type: ignore
 
         @self.server.feature(features.TEXT_DOCUMENT_PUBLISH_DIAGNOSTICS)
-        def server_cb_publish_diags(diag):  # pylint: disable=unused-variable
-            _logger.fatal("Publishing diagnostic: %s", diag)
+        def serverPublishDiagnosticsHandler(diag):  # pylint: disable=unused-variable
+            _logger.info("Publishing diagnostic: %s", diag)
             self.server_diagnostics.append(diag)
 
         self.server_thread = Thread(
@@ -219,15 +146,15 @@ class _LspHelper(unittest2.TestCase):
         self.client_diagnostics = []  # type: ignore
 
         @self.client.feature(features.WINDOW_SHOW_MESSAGE)
-        def _show_message(*args):  # pylint: disable=unused-variable
+        def clientShowMessageHandler(*args):  # pylint: disable=unused-variable
             type_ = DiagnosticSeverity(args[0][0])
             msg = args[0][1]
-            _logger.warning("[Client] [%s]: %s", type_, msg)
+            _logger.info("[Client] [%s]: %s", type_, msg)
             self.client_messages.append((type_, msg))
 
         @self.client.feature(features.TEXT_DOCUMENT_PUBLISH_DIAGNOSTICS)
-        def client_cb_publish_diags(diag):  # pylint: disable=unused-variable
-            _logger.warning("Publishing diagnostic: %s", diag)
+        def clientPublishDiagnosticsHandler(diag):  # pylint: disable=unused-variable
+            _logger.info("Publishing diagnostic: %s", diag)
             self.client_diagnostics.append(diag)
 
         self.client_thread = Thread(
@@ -252,21 +179,25 @@ class _LspHelper(unittest2.TestCase):
         self.client.lsp.send_request(features.INITIALIZED).result(LSP_REQUEST_TIMEOUT)
         _logger.info("Client server setup complete")
 
-    def tearDown(self):
-        if not getattr(self, "client", None):
-            return
-        _logger.warning("Shutting down server")
+    def tearDown(self):  # pylint:disable=inconsistent-return-statements
+        if self.__class__ is _LspHelper:
+            self.assertIsNone(getattr(self, "server", None))
+            self.assertIsNone(getattr(self, "client", None))
+            return unittest2.skip("Won't run this on %s" % self.__class__)
+        _logger.info("#" * 100)
+        _logger.info("Shutting down server")
         shutdown_response = self.client.lsp.send_request(features.SHUTDOWN).result(
             LSP_REQUEST_TIMEOUT
         )
         self.client.lsp.notify(features.EXIT)
-        _logger.debug(
-            "Threads status: server: %s, client: %s",
-            self.server_thread.is_alive(),
-            self.client_thread.is_alive(),
-        )
         self.assertIsNone(shutdown_response)
-        del self.server
+        # pygls server has cleanup routines run when the interpreter is
+        # exiting, at which point the client will be long gone. This results in
+        # RuntimeError: cannot schedule new futures after shutdown. To work
+        # around this, we're accessing its itnernal event to force it to exit
+        self.client._stop_event.set()
+        self.server_thread.join()
+        self.client_thread.join()
 
     def checkLintFileOnMethod(
         self,
@@ -306,7 +237,11 @@ class _LspHelper(unittest2.TestCase):
         with patch.object(
             self.server.checker, "getMessagesByPath", return_value=list(expected_diags),
         ):
-            self.client.lsp.send_request(method, params).result(LSP_REQUEST_TIMEOUT)
+            hdl_checker.utils.ENABLE_DEBOUNCE = False
+            try:
+                self.client.lsp.send_request(method, params).result(LSP_REQUEST_TIMEOUT)
+            finally:
+                hdl_checker.utils.ENABLE_DEBOUNCE = True
 
             self.assertTrue(
                 self.client_diagnostics, "Expected client to have diagnostics"
@@ -374,20 +309,23 @@ class _LspHelper(unittest2.TestCase):
         )
 
     def test_LintFileOnOpen(self):  # pylint: disable=inconsistent-return-statements
-        if not getattr(self, "server", None):
-            return unittest2.skip("Won't run this on the helper")
+        if self.__class__ is _LspHelper:
+            return unittest2.skip("Won't run this on %s" % self.__class__)
+        _logger.info("#" * 100)
         self._runDidOpenCheck(p.join(TEST_PROJECT, "another_library", "foo.vhd"))
 
     def test_LintFileWhenSaving(self):  # pylint: disable=inconsistent-return-statements
-        if not getattr(self, "server", None):
-            return unittest2.skip("Won't run this on the helper")
+        if self.__class__ is _LspHelper:
+            return unittest2.skip("Won't run this on %s" % self.__class__)
+        _logger.info("#" * 100)
         self._runDidSaveCheck(
             p.join(TEST_PROJECT, "basic_library", "clock_divider.vhd")
         )
 
     def test_LintFileOnChange(self):  # pylint: disable=inconsistent-return-statements
-        if not getattr(self, "server", None):
-            return unittest2.skip("Won't run this on the helper")
+        if self.__class__ is _LspHelper:
+            return unittest2.skip("Won't run this on %s" % self.__class__)
+        _logger.info("#" * 100)
         self._runDidOpenCheck(
             p.join(TEST_PROJECT, "basic_library", "clk_en_generator.vhd")
         )
@@ -398,6 +336,7 @@ class _LspHelper(unittest2.TestCase):
 
 class TestRootUriNoProjectFile(_LspHelper):
     def setUp(self):
+        _logger.info("#" * 100)
         setupTestSuport(TEST_TEMP_PATH)
         _logger.debug("Creating server")
 
@@ -405,7 +344,7 @@ class TestRootUriNoProjectFile(_LspHelper):
             patch.object(
                 hdl_checker.config_generators.base_generator.BaseGenerator, "generate",
             ),
-            patch("hdl_checker.base_server.json.dump", spec=json.dump),
+            patch("hdl_checker.core.json.dump", spec=json.dump),
         )
 
         for _patch in self.patches:
@@ -419,22 +358,25 @@ class TestRootUriNoProjectFile(_LspHelper):
             )
         )
 
-        self.maxDiff = None
-
     def tearDown(self):
-        _logger.warning("Shutting down server")
+        _logger.info("#" * 100)
+        _logger.info("Shutting down server")
         for _patch in self.patches:
             _patch.stop()
         super(TestRootUriNoProjectFile, self).tearDown()
 
-    def test_SearchesForFilesOnInitialization(self):  # pylint: disable=no-self-use
+    def test_SearchesForFilesOnInitialization(
+        self,
+    ):  # pylint: disable=no-self-use,invalid-name
+        _logger.info("#" * 100)
         lsp.SimpleFinder.generate.assert_called_once()  # pylint: disable=no-member
         #  Will get called twice
-        hdl_checker.base_server.json.dump.assert_called()  # pylint: disable=no-member
+        hdl_checker.core.json.dump.assert_called()  # pylint: disable=no-member
 
 
 class TestOldStyleProjectFile(_LspHelper):
     def setUp(self):
+        _logger.info("#" * 100)
         setupTestSuport(TEST_TEMP_PATH)
         _logger.debug("Creating server")
 
@@ -447,11 +389,10 @@ class TestOldStyleProjectFile(_LspHelper):
             ),
         )
 
-        self.maxDiff = None
-
 
 class TestNonExistingProjectFile(_LspHelper):
     def setUp(self):
+        _logger.info("#" * 100)
         setupTestSuport(TEST_TEMP_PATH)
         _logger.debug("Creating server")
         self.project_file = "__some_project_file.prj"
@@ -469,6 +410,7 @@ class TestNonExistingProjectFile(_LspHelper):
 
 class TestNoRootNoProjectFile(_LspHelper):
     def setUp(self):
+        _logger.info("#" * 100)
         setupTestSuport(TEST_TEMP_PATH)
         _logger.debug("Creating server")
         self.project_file = "__some_project_file.prj"
@@ -505,6 +447,7 @@ class TestNoRootWithProjectFile(_LspHelper):
 
 class TestValidProject(_LspHelper):
     def setUp(self):
+        _logger.info("#" * 100)
         setupTestSuport(TEST_TEMP_PATH)
         _logger.debug("Creating server")
         self.project_file = "__some_project_file.prj"
@@ -520,7 +463,7 @@ class TestValidProject(_LspHelper):
         )
 
     def runTestBuildSequenceTable(self, tablefmt):
-        _logger.fatal("############################################")
+        _logger.debug("############################################")
         very_common_pkg = Path(
             p.join(TEST_PROJECT, "basic_library", "very_common_pkg.vhd")
         )
@@ -541,9 +484,8 @@ class TestValidProject(_LspHelper):
             ),
         ]
 
-        self.maxDiff = None
         try:
-            got = self.server._getBuildSequenceForHover(clk_en_generator)
+            got = self.server.getBuildSequenceForHover(clk_en_generator)
             self.assertEqual(got, "\n".join(expected))
         except:
             _logger.error(
@@ -556,21 +498,24 @@ class TestValidProject(_LspHelper):
         (Identifier("ieee"),),
     )
     def test_ReportBuildSequencePlain(self):
+        _logger.info("#" * 100)
         self.runTestBuildSequenceTable(tablefmt="plain")
 
     @patch(
         "hdl_checker.builders.base_builder.BaseBuilder.builtin_libraries",
         (Identifier("ieee"),),
-    )
+    )  # pylint: disable=invalid-name
     def test_ReportBuildSequenceFallback(self):
+        _logger.info("#" * 100)
         with patch.object(self.server, "client_capabilities", None):
             self.runTestBuildSequenceTable(tablefmt="plain")
 
     @patch(
         "hdl_checker.builders.base_builder.BaseBuilder.builtin_libraries",
         (Identifier("ieee"),),
-    )
+    )  # pylint: disable=invalid-name
     def test_ReportBuildSequenceMarkdown(self):
+        _logger.info("#" * 100)
         with patch.object(
             self.server,
             "client_capabilities",
@@ -608,11 +553,12 @@ class TestValidProject(_LspHelper):
             self.runTestBuildSequenceTable(tablefmt="github")
 
     @patch.object(
-        hdl_checker.base_server.BaseServer,
+        hdl_checker.core.HdlCheckerCore,
         "resolveDependencyToPath",
         lambda self, _: None,
-    )
-    def test_DependencyInfoForPathNotFound(self):
+    )  # pylint: disable=invalid-name
+    def test_DependencyInfoForPathNotFound(self):  # pylint: disable=invalid-name
+        _logger.info("#" * 100)
         path = Path(p.join(TEST_PROJECT, "another_library", "foo.vhd"))
         dependency = RequiredDesignUnit(
             name=Identifier("clock_divider"),
@@ -621,16 +567,17 @@ class TestValidProject(_LspHelper):
             locations=(),
         )
         self.assertEqual(
-            self.server._getDependencyInfoForHover(dependency),
+            self.server.getDependencyInfoForHover(dependency),
             "Couldn't find a source defining 'basic_library.clock_divider'",
         )
 
     @patch.object(
-        hdl_checker.base_server.BaseServer,
+        hdl_checker.core.HdlCheckerCore,
         "resolveDependencyToPath",
         lambda self, _: (Path("some_path"), Identifier("some_library")),
     )
     def test_ReportDependencyInfo(self):
+        _logger.info("#" * 100)
         path = Path(p.join(TEST_PROJECT, "another_library", "foo.vhd"))
         dependency = RequiredDesignUnit(
             name=Identifier("clock_divider"),
@@ -639,33 +586,36 @@ class TestValidProject(_LspHelper):
             locations=(),
         )
         self.assertEqual(
-            self.server._getDependencyInfoForHover(dependency),
+            self.server.getDependencyInfoForHover(dependency),
             'Path "some_path", library "some_library"',
         )
 
-    def test_ReportDesignUnitAccordingToPosition(self) -> None:
-        UNIT_A = VhdlDesignUnit(
+    def test_ReportDesignUnitAccordingToPosition(  # pylint: disable=invalid-name
+        self,
+    ) -> None:
+        _logger.info("#" * 100)
+        unit_a = VhdlDesignUnit(
             owner=Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")),
             type_=DesignUnitType.entity,
             name="unit_a",
             locations=(Location(line=1, column=2), Location(line=3, column=4)),
         )
 
-        UNIT_B = VerilogDesignUnit(
+        unit_b = VerilogDesignUnit(
             owner=Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")),
             type_=DesignUnitType.package,
             name="unit_b",
             locations=(Location(line=5, column=6), Location(line=7, column=8)),
         )
 
-        DEP_A = RequiredDesignUnit(
+        dep_a = RequiredDesignUnit(
             name=Identifier("dep_a"),
             library=Identifier("lib_a"),
             owner=Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")),
             locations=(Location(line=9, column=10), Location(line=11, column=12)),
         )
 
-        DEP_B = RequiredDesignUnit(
+        dep_b = RequiredDesignUnit(
             name=Identifier("dep_a"),
             library=Identifier("lib_a"),
             owner=Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")),
@@ -675,12 +625,12 @@ class TestValidProject(_LspHelper):
         def getDesignUnitsByPath(self, path):  # pylint: disable=unused-argument
             if path != Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")):
                 self.fail("Expected foo.vhd but got %s" % path)
-            return {UNIT_A, UNIT_B}
+            return {unit_a, unit_b}
 
         def getDependenciesByPath(self, path):  # pylint: disable=unused-argument
             if path != Path(p.join(TEST_PROJECT, "another_library", "foo.vhd")):
                 self.fail("Expected foo.vhd but got %s" % path)
-            return {DEP_A, DEP_B}
+            return {dep_a, dep_b}
 
         patches = (
             patch.object(
@@ -701,49 +651,49 @@ class TestValidProject(_LspHelper):
             _patch.start()
 
         # Check locations outside return nothing
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(0, 0)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(0, 0)))
 
         # Check design units are found, ensure boundaries match
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(1, 1)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(1, 2)), UNIT_A)
-        self.assertIs(self.server._getElementAtPosition(path, Position(1, 7)), UNIT_A)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(1, 8)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(1, 1)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(1, 2)), unit_a)
+        self.assertIs(self.server.getElementAtPosition(path, Position(1, 7)), unit_a)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(1, 8)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(3, 3)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(3, 4)), UNIT_A)
-        self.assertIs(self.server._getElementAtPosition(path, Position(3, 9)), UNIT_A)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(3, 10)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(3, 3)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(3, 4)), unit_a)
+        self.assertIs(self.server.getElementAtPosition(path, Position(3, 9)), unit_a)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(3, 10)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(5, 5)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(5, 6)), UNIT_B)
-        self.assertIs(self.server._getElementAtPosition(path, Position(5, 11)), UNIT_B)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(5, 12)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(5, 5)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(5, 6)), unit_b)
+        self.assertIs(self.server.getElementAtPosition(path, Position(5, 11)), unit_b)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(5, 12)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(7, 7)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(7, 8)), UNIT_B)
-        self.assertIs(self.server._getElementAtPosition(path, Position(7, 13)), UNIT_B)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(7, 14)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(7, 7)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(7, 8)), unit_b)
+        self.assertIs(self.server.getElementAtPosition(path, Position(7, 13)), unit_b)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(7, 14)))
 
         # Now check dependencies
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(9, 9)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(9, 10)), DEP_A)
-        self.assertIs(self.server._getElementAtPosition(path, Position(9, 20)), DEP_A)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(9, 21)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(9, 9)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(9, 10)), dep_a)
+        self.assertIs(self.server.getElementAtPosition(path, Position(9, 20)), dep_a)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(9, 21)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(11, 11)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(11, 12)), DEP_A)
-        self.assertIs(self.server._getElementAtPosition(path, Position(11, 22)), DEP_A)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(11, 23)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(11, 11)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(11, 12)), dep_a)
+        self.assertIs(self.server.getElementAtPosition(path, Position(11, 22)), dep_a)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(11, 23)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(13, 13)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(13, 14)), DEP_B)
-        self.assertIs(self.server._getElementAtPosition(path, Position(13, 24)), DEP_B)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(13, 25)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(13, 13)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(13, 14)), dep_b)
+        self.assertIs(self.server.getElementAtPosition(path, Position(13, 24)), dep_b)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(13, 25)))
 
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(15, 15)))
-        self.assertIs(self.server._getElementAtPosition(path, Position(15, 16)), DEP_B)
-        self.assertIs(self.server._getElementAtPosition(path, Position(15, 26)), DEP_B)
-        self.assertIsNone(self.server._getElementAtPosition(path, Position(15, 27)))
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(15, 15)))
+        self.assertIs(self.server.getElementAtPosition(path, Position(15, 16)), dep_b)
+        self.assertIs(self.server.getElementAtPosition(path, Position(15, 26)), dep_b)
+        self.assertIsNone(self.server.getElementAtPosition(path, Position(15, 27)))
 
         for _patch in patches:
             _patch.stop()
@@ -753,6 +703,7 @@ class TestValidProject(_LspHelper):
         (Identifier("ieee"),),
     )
     def test_HoverOnInvalidRange(self):
+        _logger.info("#" * 100)
         self.assertIsNone(
             self.client.lsp.send_request(
                 features.HOVER,
@@ -772,6 +723,7 @@ class TestValidProject(_LspHelper):
         (Identifier("ieee"),),
     )
     def test_HoverOnDesignUnit(self):
+        _logger.info("#" * 100)
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
         very_common_pkg = p.join(TEST_PROJECT, "basic_library", "very_common_pkg.vhd")
         package_with_constants = p.join(
@@ -812,6 +764,7 @@ class TestValidProject(_LspHelper):
         (Identifier("ieee"),),
     )
     def test_HoverOnDependency(self):
+        _logger.info("#" * 100)
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
         clock_divider = p.join(TEST_PROJECT, "basic_library", "clock_divider.vhd")
 
@@ -831,8 +784,9 @@ class TestValidProject(_LspHelper):
     @patch(
         "hdl_checker.builders.base_builder.BaseBuilder.builtin_libraries",
         (Identifier("ieee"),),
-    )
+    )  # pylint: disable=invalid-name
     def test_GetDefinitionMatchingDependency(self):
+        _logger.info("#" * 100)
         source = p.join(TEST_PROJECT, "basic_library", "use_entity_a_and_b.vhd")
         target = p.join(TEST_PROJECT, "basic_library", "two_entities_one_file.vhd")
 
@@ -863,8 +817,9 @@ class TestValidProject(_LspHelper):
     @patch(
         "hdl_checker.builders.base_builder.BaseBuilder.builtin_libraries",
         (Identifier("ieee"),),
-    )
+    )  # pylint: disable=invalid-name
     def test_GetDefinitionBuiltInLibrary(self) -> None:
+        _logger.info("#" * 100)
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
 
         self.assertFalse(
@@ -881,6 +836,7 @@ class TestValidProject(_LspHelper):
         (Identifier("ieee"),),
     )
     def test_GetDefinitionNotKnown(self) -> None:
+        _logger.info("#" * 100)
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
 
         self.assertFalse(
@@ -905,12 +861,13 @@ class TestValidProject(_LspHelper):
         ],
     )
     def test_ReferencesOfAValidElement(self, get_references) -> Any:
+        _logger.info("#" * 100)
         # We'll pass the path to foo.vhd but we're patching the
         # getReferencesToDesignUnit to return "some_path"
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
 
         # Make sure we picked up an existing element
-        unit = self.server._getElementAtPosition(Path(path_to_foo), Position(7, 7))
+        unit = self.server.getElementAtPosition(Path(path_to_foo), Position(7, 7))
         self.assertIsNotNone(unit)
 
         references = [
@@ -969,11 +926,12 @@ class TestValidProject(_LspHelper):
             },
         )
 
-    def test_ReferencesOfAnInvalidElement(self):
+    def test_ReferencesOfAnInvalidElement(self):  # pylint: disable=invalid-name
+        _logger.info("#" * 100)
         path_to_foo = p.join(TEST_PROJECT, "another_library", "foo.vhd")
 
         # Make sure there's no element at this location
-        unit = self.server._getElementAtPosition(Path(path_to_foo), Position(0, 0))
+        unit = self.server.getElementAtPosition(Path(path_to_foo), Position(0, 0))
         self.assertIsNone(unit)
 
         for include_declaration in (False, True):
@@ -988,6 +946,7 @@ class TestValidProject(_LspHelper):
             )
 
     def test_changeConfiguration(self):
+        _logger.info("#" * 100)
         # pylint: disable=no-member
         with patch.object(self.server, "onConfigUpdate"):
             self.client.lsp.send_request(
