@@ -511,6 +511,7 @@ class TestExpandingPathNames(TestCase):
         expected = (
             SourceEntry(Path(x), None, (), (), ())
             for x in (
+                self.join("README.md"),
                 self.join("some_vhd.vhd"),
                 self.join("some_v.v"),
                 self.join("some_sv.sv"),
@@ -583,7 +584,12 @@ class TestFilterGitIgnoredPaths(TestCase):
             ["git", "commit", "-m", "'initial'"],
         ):
             _logger.debug("$ %s", cmd)
-            subp.check_call(cmd, cwd=self.base_path, stdout=subp.PIPE)
+            for line in (
+                subp.check_output(cmd, cwd=self.base_path)
+                .decode(errors="replace")
+                .splitlines()
+            ):
+                _logger.debug("  %s", line)
 
         _logger.debug(
             "Status:\n%s",
